<?php
/* Give (donation forms) support functions
------------------------------------------------------------------------------- */

// Theme init priorities:
// 1 - register filters, that add/remove lists items for the Theme Options
if ( ! function_exists( 'grace_church_give_theme_setup1' ) ) {
    add_action( 'after_setup_theme', 'grace_church_give_theme_setup1', 1 );
    function grace_church_give_theme_setup1() {
        add_filter( 'grace_church_filter_list_sidebars', 'grace_church_give_list_sidebars' );
        add_filter('grace_church_filter_detect_inheritance_key', 'grace_church_give_detect_inheritance_key', 9, 1);
        add_action( 'grace_church_action_add_styles', 'grace_church_give_frontend_scripts' );
    }
}


if ( !function_exists( 'grace_church_give_settings_theme_setup2' ) ) {
    add_action( 'grace_church_action_before_init_theme', 'grace_church_give_settings_theme_setup2', 3 );
    function grace_church_give_settings_theme_setup2() {
        if (grace_church_exists_give()) {
            // Add Give pages in the Theme inheritance system
            grace_church_add_theme_inheritance( array( 'give' => array(
                    'stream_template' => '',
                    'single_template' => '',
                    'taxonomy' => array('give_forms_category'),
                    'taxonomy_tags' => '',
                    'post_type' => array('give_forms'),
                    'override' => 'page'
                ) )
            );

        }
    }
}



// Theme init priorities:
// 9 - register other filters (for installer, etc.)
if ( ! function_exists( 'grace_church_give_theme_setup9' ) ) {
	add_action( 'after_setup_theme', 'grace_church_give_theme_setup9', 9 );
	function grace_church_give_theme_setup9() {
		if ( grace_church_exists_give() ) {
            add_filter('grace_church_filter_get_current_taxonomy',		'grace_church_give_post_type_taxonomy', 9, 2);
		}
		if ( is_admin() ) {
			add_filter( 'grace_church_filter_tgmpa_required_plugins', 'grace_church_give_tgmpa_required_plugins' );
		}
	}
}

// Check if plugin installed and activated
if ( ! function_exists( 'grace_church_exists_give' ) ) {
	function grace_church_exists_give() {
		return class_exists( 'Give' );
	}
}

// Check value for "on" | "off" | "inherit" values
if ( ! function_exists( 'grace_church_is_on' ) ) {
    function grace_church_is_on( $prm ) {
        return $prm > 0 || in_array( strtolower( $prm ), array( 'true', 'on', 'yes', 'show' ) );
    }
}

// Return true, if current page is any give page
if ( ! function_exists( 'grace_church_is_give_page' ) ) {
    function grace_church_is_give_page() {
        $rez = false;
        if ( grace_church_exists_give() ) {
            $rez =  is_give_form() || is_singular( 'give_forms' ) || is_give_category() || is_give_tag() || is_give_taxonomy();
        }
        return $rez;
    }
}

// Detect current blog mode
if ( ! function_exists( 'grace_church_give_detect_inheritance_key' ) ) {
        //Handler of add_filter('grace_church_filter_detect_inheritance_key',	'grace_church_give_detect_inheritance_key', 9, 1);
        function grace_church_give_detect_inheritance_key( $key ) {
        if ( grace_church_is_give_page() ) {
            $key = 'give';
        }
        return $key;
    }
}


// Filter to detect current taxonomy
if ( !function_exists( 'grace_church_give_post_type_taxonomy' ) ) {
    //Handler of add_filter('grace_church_filter_get_current_taxonomy',	'grace_church_give_post_type_taxonomy', 9, 2);
    function grace_church_give_post_type_taxonomy($tax, $page) {
        if (!empty($tax)) return $tax;
        if ( grace_church_strpos($page, 'give')!==false ) {
            $tax = 'give_forms_category';
        }
        return $tax;
    }
}


// Enqueue WooCommerce custom styles
if ( !function_exists( 'grace_church_give_frontend_scripts' ) ) {
    //Handler of add_action( 'grace_church_action_add_styles', 'grace_church_give_frontend_scripts' );
    function grace_church_give_frontend_scripts() {
        if (grace_church_exists_give())
            wp_enqueue_style( 'grace-church-give-style',  grace_church_get_file_url('css/give-style.css'), array(), null );
    }
}


// Add Give specific items into lists
//------------------------------------------------------------------------

// Add sidebar
if ( ! function_exists( 'grace_church_give_list_sidebars' ) ) {
        function grace_church_give_list_sidebars( $list = array() ) {
        $list['give_widgets'] = array(
            'name'        => esc_html__( 'Give Widgets', 'grace-church' ),
            'description' => esc_html__( 'Widgets to be shown on the Give pages', 'grace-church' ),
        );
        return $list;
    }
}


