<?php
/**
 * Plugin support: Give
 *
 * @package WordPress
 * @subpackage ThemeREX Addons
 * @since v1.6.50
 */

// Don't load directly
if ( ! defined( 'ABSPATH' ) ) { exit; }

if ( ! defined( 'TRX_ADDONS_GIVE_FORMS_PT_FORMS' ) )			define( 'TRX_ADDONS_GIVE_FORMS_PT_FORMS', 'give_forms' );
if ( ! defined( 'TRX_ADDONS_GIVE_FORMS_PT_PAYMENT' ) )			define( 'TRX_ADDONS_GIVE_FORMS_PT_PAYMENT', 'give_payment' );
if ( ! defined( 'TRX_ADDONS_GIVE_FORMS_TAXONOMY_CATEGORY' ) )	define( 'TRX_ADDONS_GIVE_FORMS_TAXONOMY_CATEGORY', 'give_forms_category' );
if ( ! defined( 'TRX_ADDONS_GIVE_FORMS_TAXONOMY_TAG' ) )		define( 'TRX_ADDONS_GIVE_FORMS_TAXONOMY_TAG', 'give_forms_tag' );


// Check if plugin is installed and activated
if ( !function_exists( 'trx_utils_exists_give' ) ) {
	function trx_utils_exists_give() {
		return class_exists( 'Give' );
	}
}

// Return true, if current page is Give plugin's page
if ( !function_exists( 'trx_utils_is_give_page' ) ) {
	function trx_utils_is_give_page() {
		$rez = false;
		if (trx_utils_exists_give()) {
			$rez = (is_single() && in_array(get_query_var('post_type'), array(TRX_ADDONS_GIVE_FORMS_PT_FORMS, TRX_ADDONS_GIVE_FORMS_PT_PAYMENT))) 
					|| is_post_type_archive(TRX_ADDONS_GIVE_FORMS_PT_FORMS) 
					|| is_post_type_archive(TRX_ADDONS_GIVE_FORMS_PT_PAYMENT) 
					|| is_tax(TRX_ADDONS_GIVE_FORMS_TAXONOMY_CATEGORY)
					|| is_tax(TRX_ADDONS_GIVE_FORMS_TAXONOMY_TAG);
		}
		return $rez;
	}
}


// Support utils
//------------------------------------------------------------------------

// Plugin init
if ( !function_exists( 'trx_utils_give_init' ) ) {
	add_action("init", 'trx_utils_give_init');
	function trx_utils_give_init() {
		if (trx_utils_exists_give()) {
			remove_action( 'give_single_form_summary', 'give_template_single_title', 5 );
		}
	}
}

// Replace single title with h2 instead h1
if ( !function_exists( 'trx_utils_give_single_title' ) ) {
	add_action("give_single_form_summary", 'trx_utils_give_single_title', 5);
	function trx_utils_give_single_title() {
		?><h2 itemprop="name" class="give-form-title entry-title"><?php the_title(); ?></h2><?php
	}
}


// Check plugin in the required plugins
if ( !function_exists( 'trx_utils_give_importer_required_plugins' ) ) {
    if (is_admin()) add_filter( 'trx_utils_filter_importer_required_plugins',	'trx_utils_give_importer_required_plugins', 10, 2 );
    function trx_utils_give_importer_required_plugins($not_installed='', $list='') {
        if (strpos($list, 'give')!==false && !trx_utils_exists_give() )
            $not_installed .= '<br>' . esc_html__('Give', 'trx_utils');
        return $not_installed;
    }
}

// Set plugin's specific importer options
if ( !function_exists( 'trx_utils_give_importer_set_options' ) ) {
    add_filter( 'trx_utils_filter_importer_options', 'trx_utils_give_importer_set_options', 10, 1 );
    function trx_utils_give_importer_set_options($options=array()) {
        if ( trx_utils_exists_give() && in_array('give', $options['required_plugins']) ) {
            $options['additional_options'][] = 'give_settings';
            if (is_array($options['files']) && count($options['files']) > 0) {
                foreach ($options['files'] as $k => $v) {
                    $options['files'][$k]['file_with_give'] = str_replace('name.ext', 'give.txt', $v['file_with_']);
                }
            }
        }
        return $options;
    }
}


// Add checkbox to the one-click importer
if ( !function_exists( 'trx_utils_give_importer_show_params' ) ) {
    add_action( 'trx_utils_action_importer_params',	'trx_utils_give_importer_show_params', 10, 1 );
    function trx_utils_give_importer_show_params($importer) {
        if ( trx_utils_exists_give() && in_array('give', $importer->options['required_plugins']) ) {
            $importer->show_importer_params(array(
                'slug' => 'give',
                'title' => esc_html__('Import Give (Donation Form)', 'trx_utils'),
                'part' => 1
            ));
        }
    }
}

// Import posts
if ( !function_exists( 'trx_utils_give_importer_import' ) ) {
    add_action( 'trx_utils_action_importer_import',	'trx_utils_give_importer_import', 10, 2 );
    function trx_utils_give_importer_import($importer, $action) {
        if ( trx_utils_exists_give() && in_array('give', $importer->options['required_plugins']) ) {
            if ( $action == 'import_give' ) {
                $importer->response['start_from_id'] = 0;
                $importer->import_dump('give', esc_html__('Give (Donation Form)', 'trx_utils'));
            }
        }
    }
}

// Check if the row will be imported
if ( !function_exists( 'trx_utils_give_importer_check_row' ) ) {
    add_filter('trx_utils_filter_importer_import_row', 'trx_utils_give_importer_check_row', 9, 4);
    function trx_utils_give_importer_check_row($flag, $table, $row, $list) {
        if ($flag || strpos($list, 'give')===false) return $flag;
        if ( trx_utils_exists_give() ) {
            if ($table == 'posts')
                $flag = in_array($row['post_type'], array('give_forms', 'give_payment'));
        }
        return $flag;
    }
}

// Display import progress
if ( !function_exists( 'trx_utils_give_importer_import_fields' ) ) {
    add_action( 'trx_utils_action_importer_import_fields',	'trx_utils_give_importer_import_fields', 10, 1 );
    function trx_utils_give_importer_import_fields($importer) {
        if ( trx_utils_exists_give() && in_array('give', $importer->options['required_plugins']) ) {
            $importer->show_importer_fields(array(
                    'slug'	=> 'give',
                    'title'	=> esc_html__('Give (Donation Form)', 'trx_utils')
                )
            );
        }
    }
}

// Export posts
if ( !function_exists( 'trx_utils_give_importer_export' ) ) {
    add_action( 'trx_utils_action_importer_export',	'trx_utils_give_importer_export', 10, 1 );
    function trx_utils_give_importer_export($importer) {
        if ( trx_utils_exists_give() && in_array('give', $importer->options['required_plugins']) ) {
            trx_utils_fpc(TRX_UTILS_PLUGIN_DIR . 'importer/export/give.txt', serialize( array(
                    'give_commentmeta' => $importer->export_dump('give_commentmeta'),
                    'give_comments' => $importer->export_dump('give_comments'),
                    'give_donationmeta' => $importer->export_dump('give_donationmeta'),
                    'give_donormeta' => $importer->export_dump('give_donormeta'),
                    'give_donors' => $importer->export_dump('give_donors'),
                    'give_formmeta' => $importer->export_dump('give_formmeta'),
                    'give_logmeta' => $importer->export_dump('give_logmeta'),
                    'give_logs' => $importer->export_dump('give_logs'),
                    'give_revenue' => $importer->export_dump('give_revenue'),
                    'give_sequental_ordering' => $importer->export_dump('give_sequental_ordering'),
                ) )
            );
        }
    }
}

// Display exported data in the fields
if ( !function_exists( 'trx_utils_give_importer_export_fields' ) ) {
    add_action( 'trx_utils_action_importer_export_fields',	'trx_utils_give_importer_export_fields', 10, 1 );
    function trx_utils_give_importer_export_fields($importer) {
        if ( trx_utils_exists_give() && in_array('give', $importer->options['required_plugins']) ) {
            $importer->show_exporter_fields(array(
                    'slug'	=> 'give',
                    'title' => esc_html__('Give (Donation Form)', 'trx_utils')
                )
            );
        }
    }
}



